# Instrumental-Downloader
A command line tool to download a song's instrumental from Youtube.

# Usage
1) cd to the /bin directory
2) use your command

<p>Command: ./instrumental_dl [filename/ songTitles..]<br><br>
  filename:     This file should have a .txt extension and be located in the /bin folder.<br>
                The file should contain a song title on each line.<br>
  songTitles:   Multiple song titles can be used as seperate arguments.<br>
                Each song title should be contained in quotes so that all the <br>
                spaces are included.<p>
